## $Id: level_results_presentation.py 10574 2013-09-01 08:11:34Z henrik $
##
## Copyright (C) 2013 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from zope.catalog.interfaces import ICatalog
from zope.component import queryUtility, getUtility
from zope.interface import implementer, Interface, Attribute
from waeup.kofa.interfaces import (
    IKofaUtils,
    academic_sessions_vocab, registration_states_vocab)
from waeup.kofa.students.interfaces import IStudentsUtils
from waeup.kofa.interfaces import MessageFactory as _
from waeup.kofa.reports import IReport
from waeup.kofa.browser.pdf import get_signature_tables


def get_students(faccode, depcode, session, level=None):
    """Get students in a certain department who registered courses
    in a certain session at a certain level.

    Returns a list of lists of student data tuples.
    """
    site = grok.getSite()
    cat = queryUtility(ICatalog, name="students_catalog")
    result = cat.searchResults(
        depcode = (depcode, depcode), faccode = (faccode, faccode)
        )
    students_utils = getUtility(IStudentsUtils)
    table = []
    for i in range(len(students_utils.gpa_boundaries)+1):
        # The last list is reserved for students with more than one
        # level in the same session.
        table.append([])
    for stud in result:
        line = (stud.student_id,
                stud.matric_number,
                stud.display_fullname,
                )
        if level is not None:
            if not stud['studycourse'].has_key(str(level)):
                continue
            level_obj = stud['studycourse'][str(level)]
            if level_obj.level_session != session:
                continue
        else:
            itemcount = 0
            for item in stud['studycourse'].values():
                if item.level_session == session:
                    level_obj = item
                    itemcount += 1
            if itemcount == 0:
                # No level registered in this session
                continue
            if itemcount > 1:
                # More than one session registered in this session
                table[len(students_utils.gpa_boundaries)].append(line)
                continue
        table[students_utils.getClassFromCGPA(level_obj.gpa)[0]].append(line)
    return table

